=========
Changelog
=========

Version 1.6.0
-------------

- 32f084a Update etos library to version 1.6.0
- 747128b Artifact from config instead of non-existing attribute (#20)
- 726285a Fix a bug with TEST_REGEX not loading properly (#19)

Version 1.5.0
-------------

- 66c6b74 Update etos library to version 1.5.0

Version 1.4.0
-------------

- 5ff16b3 Update etos library to version 1.4.0
- 97ac4e5 Send artifact events (#17)

Version 1.3.1
-------------

- 16c838f Create checkout script in workspace directory instead (#18)

Version 1.3.0
-------------

- d04469a Update etos library to version 1.3.0
- 01859dd Compress workspace after execution (#16)
- 1a82827 Run JSONTas on step definition (#15)

Version 1.2.0
-------------

- 15b1a5d Add a generic preparation step for etos-test-runner (#14)
- 219b559 Load TEST_REGEX from environment variables instead (#13)

Version 1.1.0
-------------

- 2cdc971 Update README.rst (#12)
- 1c1f257 Add CODEOWNERS file with etos maintainers (#11)
- 60ef780 Update README.rst (#10)
